@@ -13,8 +13,8 @@
 #   \item{name}{The name of the object to be replaced."}
 #   \item{pkgName}{The name of the package where the object lives."}
 #   \item{value}{The new value to be assigned.}
-#   \item{keepOld}{If @TRUE, the old value is kept as an attribute in
-#     the new object.}
+#   \item{keepOld}{If @TRUE, the old value is kept as attribute
+#     \code{oldValue} in the new object.}
 #   \item{...}{Not used.}
 # }
 #
@@ -62,8 +62,10 @@ setMethodS3("reassignInPackage", "default", function(name, pkgName, value, keepO
   if (keepOld)
     attr(value, "oldValue") <- oldValue;
 
-  unlockBinding(name, env);
-  assignInNamespace(name, value, ns=pkgName, envir=env);
+  unlockBindingT <- base::unlockBinding;
+  unlockBindingT(name, env);
+  assignInNamespaceT <- utils::assignInNamespace;
+  assignInNamespaceT(name, value, ns=pkgName, envir=env);
   assign(name, value, envir=env);
   lockBinding(name, env);
 
@@ -72,6 +74,12 @@ setMethodS3("reassignInPackage", "default", function(name, pkgName, value, keepO
 
 ############################################################################
 # HISTORY:
+# 2012-01-12
+# o CLEANUP: reassignInPackage() calls function that are considered
+#   "unsafe" by the new CRAN policies, i.e. unlockBinding() and
+#   assignInNamespace().  However, we still wish to keep this method
+#   available to advanced users.  In order to avoid getting NOTEs
+#   from R CMD check, we have "hidden" those unsafe function calls.
 # 2007-07-13
 # o Now reassignInPackage() can reassign non-exported values by using
 #   getAnywhere() instead of get().
